/*Author: Alexandre Boyer
 * Date: 26 Sept 2023
 */
/*
 * gpio.c for nucleo board L476
 */
#include "stm32l4xx_ll_bus.h"
#include "stm32l4xx_ll_gpio.h"

//#include "options.h"
#include "gpio.h"

#define LED_PORT GPIOA
#define LED_PIN LL_GPIO_PIN_5
#define BUT_PORT GPIOC
#define BUT_PIN LL_GPIO_PIN_13

void GPIO_init(void)
{
// PORT A
LL_AHB2_GRP1_EnableClock( LL_AHB2_GRP1_PERIPH_GPIOA );
// Green LED --> User LED
LL_GPIO_SetPinMode(       LED_PORT, LED_PIN, LL_GPIO_MODE_OUTPUT );
LL_GPIO_SetPinOutputType( LED_PORT, LED_PIN, LL_GPIO_OUTPUT_PUSHPULL );
#ifdef UART1_PA9_PA10
// TX
LL_GPIO_SetPinMode( GPIOA, LL_GPIO_PIN_9, LL_GPIO_MODE_ALTERNATE);
LL_GPIO_SetAFPin_8_15( GPIOA, LL_GPIO_PIN_9, LL_GPIO_AF_7 );
LL_GPIO_SetPinSpeed( GPIOA, LL_GPIO_PIN_9, LL_GPIO_SPEED_FREQ_MEDIUM );
LL_GPIO_SetPinOutputType( GPIOA, LL_GPIO_PIN_9, LL_GPIO_OUTPUT_PUSHPULL );
LL_GPIO_SetPinPull( GPIOA, LL_GPIO_PIN_9, LL_GPIO_PULL_NO );
// RX
LL_GPIO_SetPinMode( GPIOA, LL_GPIO_PIN_10, LL_GPIO_MODE_ALTERNATE );
LL_GPIO_SetAFPin_8_15( GPIOA, LL_GPIO_PIN_10, LL_GPIO_AF_7 );
LL_GPIO_SetPinSpeed( GPIOA, LL_GPIO_PIN_10, LL_GPIO_SPEED_FREQ_MEDIUM );
LL_GPIO_SetPinOutputType( GPIOA, LL_GPIO_PIN_10, LL_GPIO_OUTPUT_PUSHPULL );
LL_GPIO_SetPinPull( GPIOA, LL_GPIO_PIN_10, LL_GPIO_PULL_NO );
#endif

#ifdef UART2_PA2_PA3
// sur la nucleo standard : passerelle vers USB (CDC) 
// TX
LL_GPIO_SetPinMode( GPIOA, LL_GPIO_PIN_2, LL_GPIO_MODE_ALTERNATE);
LL_GPIO_SetAFPin_0_7( GPIOA, LL_GPIO_PIN_2, LL_GPIO_AF_7 );
LL_GPIO_SetPinSpeed( GPIOA, LL_GPIO_PIN_2, LL_GPIO_SPEED_FREQ_MEDIUM );
LL_GPIO_SetPinOutputType( GPIOA, LL_GPIO_PIN_2, LL_GPIO_OUTPUT_PUSHPULL );
LL_GPIO_SetPinPull( GPIOA, LL_GPIO_PIN_2, LL_GPIO_PULL_NO );
// RX
LL_GPIO_SetPinMode( GPIOA, LL_GPIO_PIN_3, LL_GPIO_MODE_ALTERNATE );
LL_GPIO_SetAFPin_0_7( GPIOA, LL_GPIO_PIN_3, LL_GPIO_AF_7 );
LL_GPIO_SetPinSpeed( GPIOA, LL_GPIO_PIN_3, LL_GPIO_SPEED_FREQ_MEDIUM );
LL_GPIO_SetPinOutputType( GPIOA, LL_GPIO_PIN_3, LL_GPIO_OUTPUT_PUSHPULL );
LL_GPIO_SetPinPull( GPIOA, LL_GPIO_PIN_3, LL_GPIO_PULL_NO );
#endif

#ifdef UART3_PB10_PB11
// PORT B
LL_AHB2_GRP1_EnableClock( LL_AHB2_GRP1_PERIPH_GPIOB );
// sur la carte Milliwatt : 433 MHz FSK transceiver
// TX
LL_GPIO_SetPinMode( GPIOB, LL_GPIO_PIN_10, LL_GPIO_MODE_ALTERNATE);
LL_GPIO_SetAFPin_8_15( GPIOB, LL_GPIO_PIN_10, LL_GPIO_AF_7 );
LL_GPIO_SetPinSpeed( GPIOB, LL_GPIO_PIN_10, LL_GPIO_SPEED_FREQ_MEDIUM );
LL_GPIO_SetPinOutputType( GPIOB, LL_GPIO_PIN_10, LL_GPIO_OUTPUT_PUSHPULL );
LL_GPIO_SetPinPull( GPIOB, LL_GPIO_PIN_10, LL_GPIO_PULL_NO );
// RX
LL_GPIO_SetPinMode( GPIOB, LL_GPIO_PIN_11, LL_GPIO_MODE_ALTERNATE );
LL_GPIO_SetAFPin_8_15( GPIOB, LL_GPIO_PIN_11, LL_GPIO_AF_7 );
LL_GPIO_SetPinSpeed( GPIOB, LL_GPIO_PIN_11, LL_GPIO_SPEED_FREQ_MEDIUM );
LL_GPIO_SetPinOutputType( GPIOB, LL_GPIO_PIN_11, LL_GPIO_OUTPUT_PUSHPULL );
LL_GPIO_SetPinPull( GPIOB, LL_GPIO_PIN_11, LL_GPIO_PULL_NO );
#endif

// PORT C
LL_AHB2_GRP1_EnableClock( LL_AHB2_GRP1_PERIPH_GPIOC );
// Blue button conected to pin PC13
LL_GPIO_SetPinMode( BUT_PORT, BUT_PIN, LL_GPIO_MODE_INPUT );

// pin PC10 for oscillator stability measurement
LL_GPIO_SetPinMode( GPIOC, LL_GPIO_PIN_10, LL_GPIO_MODE_OUTPUT );
LL_GPIO_SetPinOutputType( GPIOC, LL_GPIO_PIN_10, LL_GPIO_OUTPUT_PUSHPULL );

}


void LED_GREEN( int val )
{
	if	( val ) {
		LL_GPIO_SetOutputPin(   LED_PORT, LED_PIN );
	}
	else {
		LL_GPIO_ResetOutputPin( LED_PORT, LED_PIN );
	}
}

int BLUE_BUTTON()
{
	return ( !LL_GPIO_IsInputPinSet( BUT_PORT, BUT_PIN ) );
}





