/*Author: Alexandre Boyer
 * Date: 26 Sept 2023
 */
/* Project L476_blink_2023 for STM32L476 mounted on Nucleo board:
 * the user LED (mounted on pin PA-5) is flashed every second for 50 ms.
 * The time base is provided by Systick (1000 ticks per second).
 * The clock configuration is the default one (Sysclk = 80 MHz, derived from MSI and PLL).
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "gpio.h"
#include "clock.h"

#define T_LED_OFF 950 //ms
#define T_LED_ON 50 //ms

/* Private function prototypes -----------------------------------------------*/



int main(void)
{

  /*clock domains activation*/
  LL_APB2_GRP1_EnableClock(LL_APB2_GRP1_PERIPH_SYSCFG);
  LL_APB1_GRP1_EnableClock(LL_APB1_GRP1_PERIPH_PWR);

  NVIC_SetPriorityGrouping(NVIC_PRIORITYGROUP_4);


  /* Configure the system clock */
  SystemClock_Config();


  /* Initialize all configured peripherals */
  //GPIO configuration
  GPIO_init();

  //initialization of systick timer (tick period set at 1 ms)
  LL_Init1msTick( SystemCoreClock );


  while (1)
  {
	  if	( BLUE_BUTTON() )
	  		LED_GREEN(1);
	  else {
	  		LED_GREEN(0);
	  		LL_mDelay(T_LED_OFF);
	  		LED_GREEN(1);
	  		LL_mDelay(T_LED_ON);
	  		}
  }
}

// systick interrupt handler
//void SysTick_Handler()
//{
	//to be defined if systick interrupt is enabled.
//}





